==> pomp_5.11.tar.gz: pomp/README.md <==
# **pomp**

## an *R* package for statistical inference on partially observed Markov processes

[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Development Release](https://img.shields.io/github/release/kingaa/pomp.svg)](https://github.com/kingaa/pomp/releases/latest)
[![CRAN Status](https://www.r-pkg.org/badges/version/pomp?color=blue)](https://cran.r-project.org/package=pomp)
[![Last CRAN release date](https://www.r-pkg.org/badges/last-release/pomp?color=blue)](https://cran.r-project.org/package=pomp)
[![R-CMD-check](https://github.com/kingaa/pomp/actions/workflows/r-cmd-check.yml/badge.svg)](https://github.com/kingaa/pomp/actions/workflows/r-cmd-check.yml)
[![binary-build](https://github.com/kingaa/pomp/actions/workflows/binary-build.yml/badge.svg)](https://github.com/kingaa/pomp/actions/workflows/binary-build.yml)
[![test-coverage](https://github.com/kingaa/pomp/actions/workflows/test-coverage.yml/badge.svg)](https://github.com/kingaa/pomp/actions/workflows/test-coverage.yml)
[![codecov](https://codecov.io/gh/kingaa/pomp/branch/master/graph/badge.svg)](https://app.codecov.io/gh/kingaa/pomp)
![CRAN mirror monthly downloads](https://cranlogs.r-pkg.org/badges/last-month/pomp?color=yellow)
![CRAN mirror total downloads](https://cranlogs.r-pkg.org/badges/grand-total/pomp?color=yellow)
[![Dependencies](https://tinyverse.netlify.app/badge/pomp)](https://tinyverse.netlify.app/)
[![manual](https://img.shields.io/badge/manual-HTML-brown)](https://kingaa.github.io/pomp/manual/)
[![pdf-manual](https://img.shields.io/badge/manual-PDF-brown)](https://kingaa.github.io/pomp/manual/pdf/)
[![doxygen](https://img.shields.io/badge/doxygen-HTML-brown)](https://kingaa.github.io/manuals/pomp/source/html/index.html)

For installation instructions and user guides, see [the package website](https://kingaa.github.io/pomp/).

Related packages:

- [**phylopomp**](https://github.com/kingaa/phylopomp/)
- [**spatPomp**](https://github.com/kidusasfaw/spatPomp)
- [**panelPomp**](https://github.com/panelPomp-org/panelPomp/)
- [**circumstance**](https://github.com/kingaa/circumstance/)
- [**subplex**](https://github.com/kingaa/subplex/)

==> pomp_6.2.tar.gz: pomp/README.md <==
# **pomp**

## an *R* package for statistical inference on partially observed Markov processes

[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Development Release](https://img.shields.io/github/release/kingaa/pomp.svg)](https://github.com/kingaa/pomp/releases/latest)
[![CRAN Status](https://www.r-pkg.org/badges/version/pomp?color=blue)](https://cran.r-project.org/package=pomp)
[![Last CRAN release date](https://www.r-pkg.org/badges/last-release/pomp?color=blue)](https://cran.r-project.org/package=pomp)
[![R-CMD-check](https://github.com/kingaa/pomp/actions/workflows/r-cmd-check.yml/badge.svg)](https://github.com/kingaa/pomp/actions/workflows/r-cmd-check.yml)
[![binary-build](https://github.com/kingaa/pomp/actions/workflows/binary-build.yml/badge.svg)](https://github.com/kingaa/pomp/actions/workflows/binary-build.yml)
[![test-coverage](https://github.com/kingaa/pomp/actions/workflows/test-coverage.yml/badge.svg)](https://github.com/kingaa/pomp/actions/workflows/test-coverage.yml)
[![codecov](https://codecov.io/gh/kingaa/pomp/branch/master/graph/badge.svg)](https://app.codecov.io/gh/kingaa/pomp)
![CRAN mirror monthly downloads](https://cranlogs.r-pkg.org/badges/last-month/pomp?color=yellow)
![CRAN mirror total downloads](https://cranlogs.r-pkg.org/badges/grand-total/pomp?color=yellow)
[![Dependencies](https://tinyverse.netlify.app/badge/pomp)](https://tinyverse.netlify.app/)
[![manual](https://img.shields.io/badge/manual-HTML-brown)](https://kingaa.github.io/pomp/manual/)
[![pdf-manual](https://img.shields.io/badge/manual-PDF-brown)](https://kingaa.github.io/pomp/manual/pdf/)
[![doxygen](https://img.shields.io/badge/doxygen-HTML-brown)](https://kingaa.github.io/manuals/pomp/source/html/index.html)

For installation instructions and user guides, see [the package website](https://kingaa.github.io/pomp/).

Related packages:

- [**PartiallyObservedMarkovProcesses.jl**](https://github.com/kingaa/PartiallyObservedMarkovProcesses.jl):
  Experimental port of **pomp** to Julia
- [**phylopomp**](https://github.com/kingaa/phylopomp/):
  **pomp** for phylodynamics
- [**panelPomp**](https://github.com/panelPomp-org/panelPomp/):
  **pomp** for panel data
- [**spatPomp**](https://github.com/spatPomp-org/spatPomp/):
  Spatiotemporal dynamics
- [**circumstance**](https://github.com/kingaa/circumstance/):
  Experimental parallelization tools
- [**subplex**](https://github.com/kingaa/subplex/): 
  The *subplex* optimization algorithm
